#
# spec file for package jhbuild
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define moduleset 3.22
Name:           jhbuild
Version:        3.30.0~20190220
Release:        1.1
Summary:        Tool to build GNOME
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://wiki.gnome.org/Projects/Jhbuild
Source0:        %{name}-%{version}.tar.xz
Source1:        README.deps
Source2:        sample.jhbuildrc
Source99:       create-deps.sh
BuildRequires:  fdupes
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
# Packages required to pass `jhbuild sanitycheck`
Requires:       autoconf
Requires:       automake
Requires:       bison
Requires:       cvs
Requires:       docbook-xsl-stylesheets
Requires:       flex
Requires:       gettext-tools
Requires:       libtool
Requires:       python-gtk
Recommends:     %{name}-lang
Recommends:     git-core
Recommends:     patch
Recommends:     subversion
Suggests:       cvs

%description
Jhbuild is a tool used to build the whole GNOME desktop from the
git source, however, it can be used to build other projects
creating a moduleset for it.

%package recommended-deps
Summary:        Recommended dependencies to use jhbuild
Group:          Development/Tools/Building
Requires:       %{name} = %{version}
# Manual extracted deps from moduleset-3.16
Requires:       bison
Requires:       cmake
Requires:       cracklib-devel
Requires:       cups-devel
Requires:       db-devel
Requires:       doxygen
Requires:       flex
Requires:       font-util
Requires:       gettext-tools
Requires:       gperf
Requires:       intltool
Requires:       libacl-devel
Requires:       libcap-devel
Requires:       libiw-devel
Requires:       libtiff-devel
Requires:       libwebp-devel
Requires:       libyaml-devel
Requires:       makeinfo
Requires:       mpfr-devel
Requires:       pam-devel
Requires:       ppp-devel
Requires:       python-libxml2
Requires:       python-rdflib
Requires:       ragel
Requires:       raptor
Requires:       sqlite
Requires:       xmlto
Recommends:     autoconf
Recommends:     automake
# Note: the order is order in jhbuild moduleset files
## Compilers
Recommends:     gcc-c++
## From bootstrap:
Recommends:     gettext-tools
Recommends:     libtool
Recommends:     pkgconfig
Recommends:     python
## System Dependencies as defined by the moduleset configuration
# only pkg-config deps are auto extracted, as we do not have to
# worry about package names there
%(sh %{SOURCE99} %{SOURCE0} %{moduleset})

%description recommended-deps
Jhbuild is a tool used to build the whole GNOME desktop from the
git source, however, it can be used to build other projects
creating a moduleset for it.

This package will install the dependencies to build GNOME
with jhbuild, to make this tool easier to use on openSUSE

The list is extracted from the moduleset version %{moduleset}

%lang_package

%prep
%setup -q
translation-update-upstream
cp %{SOURCE1} .
cp %{SOURCE2} .

%build
NOCONFIGURE=1 gnome-autogen.sh
%configure \
	--disable-scrollkeeper \
    --enable-gui
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file jhbuild
%fdupes %{buildroot}%{python_sitelib}
%fdupes %{buildroot}%{_datadir}
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc AUTHORS HACKING MAINTAINERS NEWS README sample.jhbuildrc
%{_bindir}/jhbuild
%{python_sitelib}/jhbuild/
%{_datadir}/applications/jhbuild.desktop
%{_datadir}/jhbuild/

%files recommended-deps
%doc README.deps

%files lang -f %{name}.lang

%changelog
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 3.30.0~20190220:
  + core-deps-latest: WebKitGTK 2.23.91
  + gnome-apps-latest: hitori has switched to meson
  + world: Update gst-plugins-ugly module
  + core-deps-latest: WebKitGTK 2.23.90
  + core: Make upower use gitlab.fd.o
  + core: Make GStreamer modules use gitlab.fd.o
  + core: Add repository definition for gitlab.freedesktop.org
  + core: Remove geoip module
  + core: Remove obsolete meson args for totem
  + gnome-suites-core-latest: gnome-logs uses meson
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Nov  2 2017 luc14n0@linuxmail.org
- Update to version 3.28.0~20171102:
  + gnome-world: Remove libepc.
  + core-3.28:
  - gvfs now uses meson
  - Build NetworkManager with --disable-ovs
  - Use Meson to build at-spi2-atk
  + core-deps-3.28:
  - Enable build of libosinfo tests
  - Disable more fwupd backends
  - WebKitGTK+ 2.19.1
  + 3.28: Move xtrans to -syspeds
  + world: Tepl now uses GtkSourceView 4
  + apps-3.28: gnome-recipes depends on gnome-online-accounts
- Pass --enable-gui to configure: now GUI can be enabled/disabled
  and since it's disabled by default we must turn it on.
- Update Url to https://wiki.gnome.org/Projects/Jhbuild: current
  Jhbuild's project web page.
- Add conditional use for translation-update-upstream as it's a
  SLE-only requirement.
- Drop:
    + jhbuild-unset-config-site.patch: fixed upstream.
    + %%desktop_database_* post(un) scriplets: the functionality is
    covered by file triggers now.
    + %%defattr in '%%files lang ...' section as it's not needed.
- Adopt %%make_intall macro use as best practice instead of raw
  commands.
* Mon Jan 30 2017 adrien.plazas@suse.com
- Add install time dependencies on the packages required to pass
  `jhbuild sanitycheck`: autoconf, automake, bison, cvs,
  docbook-xsl-stylesheets, flex, gettext-tools and libtool.
* Wed Dec  7 2016 adrien.plazas@suse.com
- Add patch jhbuild-unset-config-site.patch to make JHBuild work on
  SUSE (bgo#745223).
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 3.22.0~20160920:
  + 3.22: Move gnome-calendar to core
  + 3.22: Move gnome-photos to core
  + 3.22: Move Seahorse to incubator
  + 3.22: gnome-documents doesn't support srcdir != builddir
  + 3.22: gnome-photos doesn't support srcdir != builddir
  + Updated Brazilian Portuguese translation
  + 3.22: file-roller no longer depends on nautilus
  + sysdeps-3.22: increment libarchive version
  + core-deps-3.22: add gnome-autoar
  + core-3.22: make nautilus depend on gnome-autoar
  + 3.22: build evolution with gnome-autoar support
  + 3.22: gtk+ should suggest desktop-file-utils
  + 3.22: nautilus depends on libselinux
  + 3.22: gnome-weather has conditional dependency on gnome-world
  + Revert "3.22: nautilus depends on libselinux"
  + 3.22: Always build nautilus with --disable-selinux
  + 3.22: Move e-d-s to core-deps
  + 3.22: don't remove e-d-s from meta-gnome-extended-devel-
    platform
  + 3.22: Move gnome-online-accounts to core-deps
  + core-deps-3.20: WebKitGTK+ 2.12.4
  + core-deps-3.22: Explicitly disable libavformat support in Gegl
  + 3.22: update Evolution WebKit dependencies
  + 3.22: Disable srcdir != builddir for g-o-a
  + core-deps-3.22: WebKitGTK+ 2.13.90
  + 3.22: Make gnome-builder build
  + Add some auxiliary files to .gitignore
  + docs: add comment about setting buildroot to None
  + docs: update buildroot documentation
  + core-3.22: replace nautilus intltool dep with gettext
  + 3.20: Use the gspell-1-0 branch of gspell
  + Updated Brazilian Portuguese translation
  + Updated Czech translation
  + Updated Czech translation
  + core-deps-3.20: WebKitGTK+ 2.12.5
  + 3.22: Disable gnome-user-share on non-systemd systems
  + Updated Swedish translation
  + world: Update the location of ostree
  + Disable builddir != srcdir for ostree
  + world: Add xdg-desktop-portal and friends
  + 3.22: update pinyin stack
  + Updated Polish translation
  + 3.22: Use the gnome-3-22 branch of gnome-autoar
  + core-deps-3.22: WebKitGTK+ 2.13.91
  + Add more options to XGETTEXT_OPTIONS in po/Makevars
  + 3.22: Fix osinfo-db build
  + 3.22: Tell osinfo-db to install to system
  + 3.22: libosinfo depends on osinfo-db-tools
  + 3.22: Pass correct arg to `make install` of osinfo-db
  + core-deps-3.22: appstream-glib depends on gtk+, libuuid
  + core-deps-3.22: WebKitGTK+ 2.13.92
  + Remove intltool markers from .desktop
  + Updated Polish translation
  + Updated Czech translation
  + Updated Swedish translation
  + Updated Brazilian Portuguese translation
  + autotools: Add configure to the error phases for the install
    phase
  + Updated Korean translation
  + 3.22: move gnome-code-assistance to deps section of apps
  + 3.22: add apps missing from -tested
  + 3.22: Move gnome-documents to correct metamodule
  + Updated German translation
  + 3.22: Build glib with --disable-libmount
  + core-deps-3.22: WebKitGTK+ 2.14.0
* Sat Aug 20 2016 zaitor@opensuse.org
- Update to version 3.21.1~20160819:
  + 3.20: Use 2.34 branch of gdk-pixbuf
  + 3.20: Use 3.20 branch of gnome-online-accounts
  + 3.20: Use gnome-3-20 branch of gnome-logs
  + 3.20: Use the gnome-3-20 branch of epiphany
  + 3.20: Use the gnome-3-20 branch of adwaita-icon-theme
  + 3.20: Use the gnome-3-20 branch of at-spi2-atk
  + 3.20: Use the gnome-3-20 branch of gtksourceview
  + 3.20: Use the gnome-3-20 branch of gnome-settings-daemon
  + 3.20: Use the gnome-3-20 branch of gnome-characters
  + 3.20: Use the gnome-3-20 branch of robots
  + 3.20: Use the gnome-3-20 branch of evince
  + 3.20: Use the gnome-3-20 branch of gnome-nibbles
  + 3.20: Use the gnome-3-20 branch of baobab
  + 3.20: Use the gnome-3-20 branch of vinagre
  + 3.20: Use the gnome-3-20 branch of gnome-maps
  + core-deps-3.20/3.22: WebKitGTK+ 2.12.1
  + mono: update to version 4.4.0.122
  + gtk-sharp is now pointing to master and there is a new
    gtk-sharp-2
  + 3.22: Since we pass --enable-python3 to libpeas, pygobject is
    mandatory
  + Revert "3.20: Build vte and gnome-terminal from gnome-3-18"
  + 3.20: use the gnome-3-20 branch of gnome-terminal
  + 3.22: build vte and gnome-terminal from master
  + 3.22: uninstall vte before install
  + 3.20: use the gnome-3-20 branch of nautilus
  + vte: require gnutls since it is used in vtestream-file
  + bootstrap: Update gettext
  + core-deps:3.22: Add Graphene
  + Updated Swedish translation
  + Branches are done for my modules.
  + 3.14: grilo* should be using the 0.2.x branch
  + 3.20: Use stable branches of mutter/gnome-shell
  + 3.20: Use the 0.32 branch of vala
  + core-deps-3.20/3.22: WebKitGTK+ 2.12.2
  + core-3.22: Remove cogl/clutter deps from mutter
  + 3.22: mutter needs --disable-wayland-egl-server in non-wayland
    builds
  + 3.20: remove dependencies on libsystemd-{login,daemon}
  + systeminstall: ignore pkg-config files from emscripten path
  + 3.20: glib is now branched
  + 3.20: branch libsoup
  + defaults: switch to 3.22
  + Updated Swedish translation
  + gnome-world: Update for xdg-app -> flatpak rename
  + 3.20: use the gnome-3-20 branch of gvfs
  + core-deps-3.20/3.22: WebKitGTK+ 2.12.3
  + Updated Portuguese translation
  + 3.22: gnome-color-manager needs appstream-glib to run
    autogen.sh
  + 3.22: GLib's dtrace support isn't compatible with FreeBSD
  + 3.22: Fix openssl.pc workaround for FreeBSD
  + 3.22: Drop liblzma.pc workaround for FreeBSD
  + 3.22: Drop libarchive.pc workaround for FreeBSD
  + 3.22: gnome-boxes, gnome-logs, gnome-initial-setup only build
    on Linux
  + 3.22: Update spice-gtk to 0.7.1
  + core-deps-3.22: WebKitGTK+ 2.13.1
  + core-deps-3.20: use the gtkmm-3-20 branch of gtkmm
  + Default to builddir != srcdir
  + core-3.22: Disable builddir != srcdir for PulseAudio
  + core-deps-3.22: Disable non-srcdir builds for failing modules
  + apps-3.22: Disable non-srcdir builds for libgames-support
  + core-3.22: Disable non-srcdir builds on more Vala-based modules
  + core-deps-3.22: Disable non-srcdir builds for uhttpmock
  + core-3.22: Disable non-srcdir builds for upower
  + core-deps-3.22: Disable non-srcdir builds for libvte
  + core-deps-3.22: Disable non-srcdir builds for ibus and friends
  + core-deps-3.22: Disable non-srcdir builds for tracker
  + core-deps-3.22: Disable non-srcdir builds for clutter-gst
  + core-deps-3.22: Disable non-srcdir builds for valadoc
  + core-3.22: Disable non-srcdir builds for orca
  + core-3.22: Disable non-srcdir builds for mission-control
  + core-deps-3.22: Disable non-srcdir builds for gom
  + core-deps-3.22: Disable non-srcdir builds for glibmm
  + Revert "core-deps-3.22: Disable non-srcdir builds for gom"
  + core-deps-3.22: Disable non-srcdir builds for telepathy-logger
  + core-deps-3.22: Disable non-srcdir builds for folks
  + core-3.22: Disable non-srcdir builds for Rygel
  + core-3.22: Disable non-srcdir builds for totem
  + Revert "core-3.22: Disable non-srcdir builds for orca"
  + Updated Turkish translation
  + Pin gitg to gnome-3-20 stable
  + autogen.sh: Allow running in non-srcdir
  + Move java-gnome to gnome-world
  + world: aisleriot will live here forever
  + 3.22: Upgrade bluez
  + 3.22: gnome-session now depends on EGL and GLES
  + Drop brasero to gnome-world
  + Move research.operationaldynamics.com to gnome-world
  + Move gtk+-2 to gnome-world
  + Revert "core-deps-3.22: Disable non-srcdir builds for
    clutter-gst"
  + Revert "Move gtk+-2 to gnome-world"
  + WebKit really should not depend on GTK+ 2
  + Updated Brazilian Portuguese translation
  + Boxes does not support srcdir != builddir
  + 3.22: Drop unnecessary gnome-themes-standard deps
  + 3.22: remove uncrustify
  + 3.22: mark more modules that don't support srcdir != builddir
  + 3.22: Temporarily branch gtksourceview and gedit and builder
  + Revert "3.22: Temporarily branch gtksourceview and gedit and
    builder"
  + 3.22: gitg doesn't support srcdir != builddir
  + core-deps-3.22: WebKitGTK+ 2.13.2
  + 3.22: Update gnome-bluetooth dependencies
  + 3.22: Update gnome-desktop modules
  + 3.22: Fix gnome-desktop dependency
  + apps-3.18: use the gnome-builder-3-18 branch of gnome-builder
  + apps-3.20: use the gnome-builder-3-20 branch of gnome-builder
  + apps-3.18: get libgit2-glib as a tarball
  + core-3.20: use the gnome-3-20 branch of gedit
  + core-3.20: use the gnome-3-20 branch of gnome-calculator
  + core-3.20: use the gnome-3-20 branch of gnome-clocks
  + Fix udev vs. libudev typo.
  + 3.22: Disable udev for gnome-desktop on non-Linux systems
  + core-deps-3.22: Add libgepub
  + 3.22: gnome-documents needs libgepub
  + core-deps-3.22: Disable libstemmer dep for appstream-glib
  + core-3.20: use the gnome-3-20 branch of gnome-documents
  + Add bindinator
  + 3.22: drop nemiver, gdl
  + Revert "3.22: drop nemiver, gdl"
  + Revert "Boxes does not support srcdir != builddir"
  + Revert "core-3.22: Disable non-srcdir builds for totem"
  + gnome-world: Update shotwell
  + 3.22: gnome-software needs libsecret
  + core-3.22: Disable builddir for gnome-boxes
  + 3.22: Track GStreamer master branch (to be 1.10)
  + 3.22: Bring back libgnomekbd
  + core-deps-3.22: yelp-tools doesnt depend on intltool
  + core-deps-3.22: zenity doesn't depend on intltool
  + 3.22: gnome-sudoku now depends on m4-common
  + bootstrap: Update gettext to 0.19.7
  + world: Add gvfs to gnome-games deps
  + world: Add grilo and grilo-plugins to gnome-games deps
  + core-deps: Use librest stable branch
  + world: Set default PySol path for aisleriot on FreeBSD
  + 3.22: gvfs admin backend only supports Linux
  + core-deps-3.22: WebKitGTK+ 2.13.3
  + 3.22: empathy now depends on clutter-gst3
  + apps-3.22: Remove clutter-gst(2)
  + Add Language headers to po files
  + world: Fix gnome-games and deps build
  + Revert "world: Fix gnome-games and deps build"
  + core-deps-3.22: libgtop doesnt depend in intltool anymore
  + bootstrap: Update gettext to 0.19.8
  + core-deps-3.22: WebKitGTK+ 2.13.4
  + core-deps-3.22: libgnomekbd doesnt depend on intltool anymore
  + 3.22: Update gnome-chess dependencies
  + 3.22: Move gettext to core-deps
  + 3.22: glib depends on gettext
  + 3.22: Build network-manager-applet --without-team
  + Updated German translation
  + world: Add libgtkflow
  + Add support for Meson build system
  + Updated POTFILES.in
  + remove 'dist' part from meson support as it doesn't exist
  + don't look into meson internal files during configure step
  + build: distribute meson.py in tarballs
  + let meson produce optimised debug builds by default
  + 3.22: update Nautilus dependencies
  + 3.18: add branches
  + world: add lollypop
  + 3.22: libgames-support is now libgnome-games-support
  + 3.22: Mines depends on libgnome-games-support
  + 3.22: gettext-bin is gone
  + 3.22: epiphany no longer depends on libwnck
  + 3.22: Update ibus to 1.5.14
  + 2048: libgames-support => libgnome-games-support
  + core-3.20: use the gnome-3-20 branch of gnome-control-center
  + Updated Czech translation
  + Updated Polish translation
  + 3.22: Update for libosinfo package split
  + 3.20: Update for libosinfo package split
- Bump defined moduleset to 3.22.
* Wed Apr  6 2016 zaitor@opensuse.org
- Update to version 3.20.0~20160406:
  + world: point to 3.20
  + apps: gnome-clocks doesnt depend on libnotify since long time
    ago
  + core: g-c-c and nautilus doesnt depend on libnotify since long
    time ago
  + 3.20: Keep using GStreamer 1.6 branches
  + 3.18: Use the gtk-3-18 branch
  + world: Use 1.6 branch for gst-python
  + 3.18: Update some branches
  + core-deps-3.20: fix gobject-introspection python dependency
  + 3.20: Make cairo a sysdep
  + 3.20: Get rid of suggests that are causing circular dependency
    issues
  + world: add gspell
  + world: update latexila dependencies
  + Branches are done for my modules.
  + Oops...
  + Oops, bis.
  + Update some sourceforge project links
  + core-deps-3.20: Really fix libwacom download link
  + core-deps-3.20: Hold grilo and grilo-plugins on 0.2.x branch
  + core-deps-3.18/3.20: WebKitGTK+ 2.10.1
  + 3.18: Polari has branched
  + core-3.20: gnome-contacts doesnt depend on libnotify
  + apps-3.20: Upgrade fwudp to 0.5.1
  + core-deps-3.18/3.20: WebKitGTK+ 2.10.2
  + 3.18: mutter, gnome-shell + extension have branched
  + apps: Add m4-common dependency to polari
  + world: retro-plugins-* don't skip autogen
  + world: Add retro-plugins-pce
  + world: Update adress of gnome-games repo
  + 3.18: GtkSourceView and gedit have branched
  + 3.20: Target grilo 0.3.x for GNOME 3.20
  + 3.20: Fix grilo* module definitions
  + default: switch to build 3.20
  + 3.20: remove intltool dependency for GtkSourceView
  + gnome-world: Update retro-gtk dependencies
  + world: Add libratbag
  + 3.20: Move fontconfig back to -sysdeps
  + 3.20: Move itstool to -sysdeps
  + Remove itstool patch
  + 3.18: branch modules on gnome-3-18
  + 3.20: Remove dleyna-renderer
  + 3.20: Drop gnome-music to gnome-world
  + 3.20: Add note on why aisleriot is in gnome-world
  + core-deps-3.18/3.20: WebKitGTK+ 2.10.3
  + 3.20: Move libgames-support to gnome-apps
  + 3.20: Refresh Nibbles dependencies
  + 3.18: Use the 0.30 branch of vala
  + minor style fix
  + core-deps-3.20: WebKitGTK+ 2.11.1
  + 3.20: Move libndp to sysdeps
  + 3.20: Move lcms2 to -sysdeps
  + 3.20: Move libpwquality to -sysdeps
  + 3.20: Move libepoxy to -sysdeps
  + 3.20: Move libevdev to -sysdeps
  + 3.20: Move xwayland to -sysdeps
  + 3.20: Move libXi to -sysdeps
  + sysid: add a missing space in get_freebsd_info
  + install-check: Drop as no longer useful and potentially
    dangerous
  + core-deps-3.18: WebKitGTK+ 2.10.4
  + 3.18: branch gnome-session
  + 3.20: update dependencies for the spell checking
  + modulesets: move gspell from gnome-world to
    gnome-suites-core-deps
  + 3.20: add wayland-protocols for weston
  + 3.20: gobject-introspection depends on python2-devel
  + Updated Czech translation
  + Updated Czech translation
  + 3.18: libgusb needs a dependency on libusb1
  + 3.20: add missing version field to libusb1
  + 3.18: fix libwacom module path
  + 3.20: move libusb1 from sysdeps to core-deps
  + 3.20: libgusb needs a dependency on libusb1
  + 3.18: Fix lcms2 module path
  + 3.18: move libusb1 from sysdeps to core-deps
  + 3.18: move libxml2 from sysdeps to core-deps
  + 3.18: branch tracker
  + Fixed typo fron -> from
  + Czech translation
  + Add Czech language
  + core-deps-3.20: WebKitGTK+ 2.11.2
  + Updated Spanish translation
  + 3.20: Add wayland-protocols to the gtk+ deps
  + Revert "3.20: move libusb1 from sysdeps to core-deps"
  + 3.20: vala provides libvala-0.32.pc now
  + Revert "3.20: Drop gnome-music to gnome-world"
  + info: add a --installed option
  + docs: document the --install option of the info command
  + 3.20: declare geoclue as a dependency of gnome-weather
  + Updated Portuguese translation
  + Updated Polish translation
  + Updated Czech translation
  + Updated Czech translation
  + 3.20: Disable SELinux for Nautilus on non-Linux systems
  + gtkmm branched for 3.18
  + Updated Indonesian translation
  + apps: Remove glu dependency from gnome-chess
  + 3.18: Track gnome-3-18 for gsettings-desktop-schemas
  + Updated Spanish translation
  + Updated Spanish translation
  + 3.20: update gspell dependencies
  + Updated Slovenian translation
  + Updated Swedish translation
  + world: Switch to GNOME infrastructure for gnome-news
  + core-deps: Disable FTL JIT for WebKit
  + moduleset.dtd: Allow using <cmakeargs> in <if>
  + moduleset.rnc: The order of <dep> and <if> is not significant
  + sysdeps: Support alternative dependencies
  + sysdeps: Include alternative dependencies in --dump
  + docs: Document <altdep> tag
  + sysdeps-3.18/3.20: Add alternative c_include for llvm and clang
  + world: Add the missing branch tag for gnome-news
  + core-deps-3.18/3.20: Move --enable-evdev-input to a separate
    condition for clutter
  + 3.20: Move zeitgeist to a suggests
  + Updated Brazilian Portuguese translation
  + doc: Fix typos
  + Updated Czech translation
  + core-3.20: sushi depends on clutter-gst3
  + 3.18: gdm and gvfs branched
  + libgit2: update to version 0.23.4
  + 3.20: gnome-weather now depends on m4-common
  + apps-3.20: gitg doesnt depend on WebKit anymore
  + 3.20: libgweather depends on m4-common
  + gnome-world.module: Update some pitivi dependencies
  + sysdeps-3.20: Increase gettext requirement to 0.19
  + m4-common has been moved to git.gnome.org
  + Updated Brazilian Portuguese translation
  + core-3.18: Fix missing slash
  + core-deps: vte requires unreleased pcre2
  + core-3.18: clutter-gtk branched
  + core-deps-3.18: glibmm branched for 2.46
  + core-deps-3.18: peg libwnck before GTK+ 3.19.x dep
  + core-deps-3.18: vte branched
  + Add Pacman systeminstall backend
  + Add 'docbook-xml' sysdep
  + Use upstream gettext instead intltool
  + gnome-apps: Ensure that gegl's JPEG and PNG sources are built
  + gnome-apps: Update gnome-photos dependencies
  + 3.20: Add new gnome-photos dependencies
  + Updated Brazilian Portuguese translation
  + Improve error handling of Pacman backend
  + 3.20: Add libjasper as a sysdep so that gegl can load JPEG 2000
  + Updated German translation
  + core-deps-3.20: Fix building cogl on osx
  + core-deps-3.20: Fix building clutter on osx
  + Updated Polish translation
  + build: Remove use of gnome-autogen.sh in autogen.sh
  + core-deps-3.20: colord needs the spotread tool from argyll
  + autogen.sh: Do not check for intltool, but upstream autopoint
  (gettext)
  + 3.20: Replace gnome-packagekit with gnome-software
  + 3.20: Replace gnome-system-logs with gnome-logs
  + 3.20: Replace gucharmap with gnome-characters
  + 3.20: Move file-roller to gnome-suites-core
  + 3.20: Move orca to gnome-suites-core
  + 3.20: move gnome-initial-setup to gnome-suites-core
  + 3.20: Move gnome-dictionary to -apps
  + 3.20: Move cheese to gnome-suite-core
  + Remove gnome-packagekit from meta-gnome-apps-tested
  + Updated Brazilian Portuguese translation
  + Updated German translation
  + core-deps-3.20: WebKitGTK+ 2.11.3
  + core-deps-3.20: Re-add pcre2 and update it to 10.21-RC1
  + core-deps-3.20: Update pcre2 to 10.21
  + sysdeps-3.20: add libpcre
  + Updated Czech translation
  + 3.20: Update meta-gnome-core-utilities and
    meta-gnome-core-shell
  + Updated Polish translation
  + 3.20: Remove obsolete suggests from Epiphany
  + 3.20: Move gnome-code-assistance to -apps: gnome-builder
    depends on it
  + Updated Spanish translation
  + Updated Spanish translation
  + 3.20: Add gexiv2 as a dependency of gnome-photos
  + core-deps-3.20: WebKitGTK+ 2.11.4
  + core-deps-3.18: WebKitGTK+ 2.10.5
  + modulesets/gnome-suites-core-deps-3.20.modules: Add pyatspi2
  + apps-3.20: Move weston back to wayland moduleset
  + Revert "3.20: Remove dleyna-renderer"
  + apps-3.20: gnome-photos doesnt depend in gobject-introspection
  + 3.20: Drop aisleriot from meta-gnome-apps-tested
  + Revert "Revert "3.20: Remove dleyna-renderer""
  + 3.20: Use a header file to detect libjasper
  + core-deps-3.20: Disable FTL JIT for WebKit on FreeBSD
  + Updated Brazilian Portuguese translation
  + 3.20: Add libraw as a dependency of gegl so that it can load
    RAW images
  + gnome-world: Remove hamster-applet
  + gnome-world: Remove Labyrinth
  + core-deps-3.18: WebKitGTK+ 2.10.6
  + build: disable gettext if not found and using simple autogen.sh
  + misc: allow unaccented characters when approving for wipe
  + misc: mark script/jhbuild as executable during 'make'
  + simple install: Use CC and CFLAGS from environment
  + tarball: delay check for writable tarballdir
  + doc: clean a wrong placed and repeated paragraph
  + linux: remove obsolete call to get_dependencies
  + cmake: Add support for skip-install
  + gnome-suites-core: add libsoup as dependency for
    gnome-calculator
  + modulesets: Add ‘autoconf-archive’ as a comment above m4-common
  + Udated Czech translation
  + Updated Swedish translation
  + Updated Slovenian translation
  + 3.20: Remove empathy from core
  + 3.20: Remove farstream and telepathy-farstream from core-deps
  + Revert "3.20: Move gnome-dictionary to -apps"
  + 3.20: Merge meta-gnome-core-extras into meta-gnome-core
  + 3.20: Rearrange core
  + 3.20: Move libzapojit to core-deps
  + 3.20: Move libgfbgraph to core-deps
  + 3.20: Move gnome-online-miners to core-deps
  + 3.20: Move gnome-documents to core
  + 3.20: Move gnome-color-manager to core
  + 3.20: Alphabetize gnome-color-manager deps and add libtiff
  + 3.20: alphabetize core-deps
  + 3.20: Add a comment to the WebKit module
  + 3.20: Move zeitgeist to world
  + 3.20: Move gtk-engines to world
  + 3.20: Remove core-deps categories, alphabetize
  + 3.20: Move babl to core-deps
  + 3.20: Move gegl to core-deps
  + 3.20: Add meta-gnome-core-incubator moduleset
  + 3.20: Move gnome-photos to core (incubator)
  + 3.20: Move gnome-music to core (incubator)
  + 3.20: Move dependencies of gnome-boxes to core-deps
  + 3.20: Move gnome-boxes to core
  + 3.20: Move gnome-clocks to core
  + 3.20: Move gnome-maps to core
  + 3.20: Move gnome-weather to core
  + 3.20: Remove ConsoleKit from core
  + 3.20: Move gnome-calendar to core
  + 3.20: Bijiben now requires evolution-data-server
  + 3.20: Move bijiben to core (incubator)
  + 3.20: Move gnome-chat to core (incubator)
  + 3.20: Drop Epiphany to incubator
  + 3.20: Split games into meta-gnome-games
  + 3.20: Organize gnome-apps
  + 3.20: Move gnome-getting-started-docs to core
  + 3.20: Move anjuta and gda to gnome-world
  + 3.20: aisleriot was moved to world...
  + 3.20: Move Empathy to apps
  + 3.20: Move Empathy to apps
  + 3.20: Alphabetize libgames-support
  + 3.20: Move gnome-news to core (incubator)
  + 3.20: Add Dictionary to incubator
  + 3.20: Move gedit to core
  + 3.20: Move incubator to gnome-apps
  + 3.20: Fix alphabetization
  + Revert "Revert "Revert "3.20: Remove dleyna-renderer"""
  + 3.20: Move speech-dispatcher back to core-deps
  + Fix XML
  + 3.20: Make it validate
  + Revert "Revert "Revert "Revert "3.20: Remove dleyna-renderer""""
  + 3.20: folks should not suggest zeitgeist
  + 3.20: Keep Boxes in gnome-apps for now
  + 3.20: Fix metamodules after previous commit
  + 3.20: gedit is in too many metamodules
  + 3.20: Move clutter-gst2 to -apps
  + 3.20: Builder depends on Vala
  + 3.20: Remove Epiphany's suggests
  + 3.20: Move libical to -sysdeps
  + Updated Brazilian Portuguese translation
  + 3.20: libical 1.0.1 sets its version number as 1.0 in
    libical.pc
  + core-deps-3.20: Build gobject-introspection against python3
  + Don't redundantly pass --disable-Werror to autotools modules
  + core-deps-3.20: WebKitGTK+ 2.11.5
  + core-deps-3.20: Use python3-devel everywhere to avoid
    confusions
  + Make exception raising/handling Python3-compatible
  + 3.20: Update ibus-libpinyin
  + apps:3.20: Add libpeas dep to gnome-todo
  + autotools: Pass --disable-Werror before, not after, user flags
  + Updated Spanish translation
  + 3.20: Have Nibbles explicitly depend on libgee
  + 3.20: Robots now depends on libgames-support
  + 3.20: Klotski now depends on libgames-support
  + 3.20: Maps depends on glib-networking
  + 3.20: Move rygel to meta-gnome-core-shell
  + world: add feed reader
  + Add virtual sysdeps afer merging module sets
  + autotools: add a "bootstrap" attribute to skip default
    dependencies
  + Fix rnc validation by adding the new bootstrap attribute there
    as well.
  + make check: validate moduleset.rnc using trang and xmllint
  + 3.20: Move gnome-chat back to -world
  + 3.20: Move gnome-news back to -world
  + world: Update duplicity tarball
  + core-deps-3.20: WebKitGTK+ 2.11.90
  + 3.20: libinput now depends on libwacom
  + core-deps-3.20: There is no FreeBSD-specific FTL JIT bug now
  + 3.20: branch vte
  + core-3.20: Add dependency from gnome-software to gtkspell-3
  + core-deps-3.20: Add docbook-utils, fwupd dependencies
  + 3.20: Build vte and gnome-terminal from gnome-3-18
  + 3.18: More modules branched
  + world: Anjuta only supports libgda 4 and 5
  + sysdeps-3.20: Add libusb 1.0.9 to keep compatibility with
    FreeBSD
  + core-deps-3.20: WebKitGTK+ 2.11.91
  + 3.20: Track GStreamer master branch (to be 1.8)
  + 3.20: Build e-d-s with --disable-google-auth
  + world: Remove retro-gtk-demo and libretro-free
  + world: Remove jsk
  + 3.20: appstream-glib now depends on json-glib
  + Updated Korean translation
  + The libsigc++2 git repo was renamed to libsigcplusplus.
  + 3.18,3.20: libosinfo moved to gitlab
  + Specify branches for libxml++.
  + 3.20: Put Calendar in Incubator
  + Updated Slovak translation
  + 3.20: Update external fwupd version
  + core-deps-3.18: WebKitGTK+ 2.10.8
  + 3.20: Put Boxes in Incubator
  + 3.20: Restore gegl's inadvertently-removed dep on libraw
  + Add GNOME 3.22 modulesets
  + 3.20: gnome-session has branched early
  + 3.18/3.20: Branch gobject-introspection
  + Added Serbian translation
  + libgit2: update to version 0.24.0
  + Updated Glade branch for GNOME 3.20 release
  + apps-3.22: libgit2: update to version 0.24.0
  + core-deps-3.20/3.22: WebKitGTK+ 2.11.92
  + core-deps-3.18: WebKitGTK+ 2.10.9
  + gnome-world: add back notification-daemon
  + Revert "Remove itstool patch"
  + core-deps-3.18: use gnome-3-14 branch for libwnck
  + Updated Indonesian translation
  + apps-3.18: use glade-3-18 branch for glade
  + apps-3.18: use gnome-3-18 branch for devhelp
  + 3.20: Use gnome-3.20 branch for gnome-calendar
  + 3.20: Use the gnome-3-20 branch for gnome-todo
  + 3.20: Use the gnome-3-20 branch for gnome-photos
  + 3.20: Use the gnome-3-20 branch for gnome-boxes
  + 3.20: Use the gnome-3-20 branch of evolution-data-server
  + 3.20: Use the gnome-3-20 branch of atk
  + 3.20: Use the gnome-3-20 branch of tali
  + 3.20: WebKitGTK+ 2.12.0
  + WebKitGTK+ 2.12.0 also for 3.22
  + 3.20: gnome-color-manager depends on appstream-glib
  + world: Remove retro-gobject
  + world: Update gnome-games and retro-* repos
  + 3.20/3.22: Track GStreamer 1.8 branch
  + 3.20: Use the gtk-3-20 branch for GTK+
  + apps: fix gitg dependencies
  + Rebase gnome-world on 3.22
  + 3.18: Use the pangomm-2-38 branch of pangomm.
  + core-deps-3.20: use glibmm-2-48 branch
  + 3.20: Stable branch for Rygel
  + 3.22: Use libsigc++'s 2.10 branch.
  + 3.22: Move Boxes to core
  + 3.22: Meant to put gtk-vnc in core-deps
  + 3.20: Use the gnome-3-20 branch of evolution
  + 3.20: Use the gnome-3-20 branch of orca
- Bump define moduleset to 3.20
* Mon Oct  5 2015 zaitor@opensuse.org
- Update to version 3.18.0~20151004:
  + core/3.16: Clutter has been branched
  + Updated Korean translation
  + Updated Indonesian translation
  + 3.16: gnome-dictionary was branched
  + world: Use branch 3.14 of opal and 2.14 of ptlib
  + 3.16: Rygel branched
  + world: update gstreamer-vaapi repo to github
  + 3.16: branch glib-networking
  + 3.16: branch gvfs
  + core-deps-3.14: WebKitGTK+ 2.6.6
  + add support for a <redirect/> tag, to be used when modulesets
    are moved
  + core-3.16: Evince branched
  + world: gnome-2048 depends on libgames-support
  + update hicolor-icon-theme to 0.15
  + core-deps-3.16: WebKitGTK+ 2.8.1
  + core-3.16: mutter, gnome-shell and -extensions branched
  + apps-3.16: Polari has branched
  + 3.16: contacts and calendar branched
  + autotools: Fix XML attribute name for
    ‘supports-static-analyzer'
  + doc: Add documentation for the static analysis feature
  + 3.16: gedit and gtksourceview branched
  + add 3.18
  + 3.18: switch evolution / evolution-data-server to master
  + gnome-world: remove gnome-flashback
  + core-deps-3.16: libgweather branched
  + apps-3.18: update to qqwing 1.3.4
  + 3.18: Use the master branch of vala
  + Updated Spanish translation
  + core-deps-3.18: Use master of clutter
  + core-3.18: Use master of glib-networking
  + Updated Brazilian Portuguese translation
  + 3.18: Add gcr as a dependency of gvfs
  + 3.14: branch a bunch of modules
  + 3.16: branch a bunch of modules
  + world: Add gjs and pygobject as dependencies of gnome-builder
  + world: Update dependencies for Almanah
  + Bring back a still-needed patch
  + 3.16: Branch gobject-introspection
  + core-deps-3.18: WebKitGTK+ 2.9.1
  + core-deps-3.16: WebKitGTK+ 2.8.2
  + 3.16: Remove old libpeas deps
  + 3.18: Remove old libpeas deps
  + core-deps-3.16: WebKitGTK+ 2.8.3
  + core-deps-3.18: WebKitGTK+ 2.9.2
  + world: Add dependency on appdata-tools to Almanah
  + jhbuild: Set default tarballdir to ~/.cache/jhbuild/downloads
  + jhbuild: Define xdg_cache_home as a config variable
  + Updated Spanish translation
  + Build WebKit with ld.bfd
  + Added Portuguese translation
  + 3.18: Maps requires folks & libgee
  + 3.18: Update libwacom to latest upstream
  + epiphany: branch for 3.16
  + Add fwupd
  + apps-3.18: gnome-software depends on fwupd
  + modulesets: add libpeas to gnome-builder dependencies
  + apps-3.18: gnome-software only depends on fwupd on linux
  + autotools: restore autoreconf support
  + world: add vte dependency to gnome-builder
  + Add randrproto as a dependency of xwayland
  + core-deps-3.14/3.16/3.18: Remove libxkbcommon autogenargs
  + environment: Add the default search path to MANPATH on *BSD
  + Don't crash when the notification service is not available
  + Delete GNU Texinfo dir file and handle it with a trigger
  + xml dep_type: reverse check to the path of the docbook XML
    catalog
  + Updated Spanish translation
  + Updated Spanish translation
  + bootstrap: Add m4-common
  + Updated Slovak translation
  + Updated Czech translation
  + Move gnome-builder and uncrustify to gnome-apps
  + 3.16: branch libsoup
  + core-deps-3.18: WebKitGTK+ 2.9.3
  + Yelp now depends on modern WebKit
  + libgit2: update to version 0.23.0-rc1
  + Updated Portuguese translation
  + bootstrap: Update gettext
  + bootstrap: Update the version of automake
  + bootstrap: Bump m4
  + bootstrap: Bump up to autoconf 2.69
  + bootstrap: Bump up to Python 2.7.10
  + bootstrap: Bump up pixman to 0.32.6
  + libgit2: update to version 0.23.0
  + 3.18: Track GStreamer master (future 1.6)
  + Revert "libgit2: update to version 0.23.0"
  + Revert "libgit2: update to version 0.23.0-rc1"
  + "Tag" libgit2-glib
  + core-deps-3.16: WebKitGTK+ 2.8.4
  + gnome-apps-3.18: add phodav
  + gnome-apps-3.18: spice-gtk with webdav
  + gnome-apps-3.18: add libgovirt
  + Updated Slovenian translation
  + retro-gobject: Use autogen with Vala
  + retro-gtk: Use autogen with Vala
  + retro-gtk: Update dependencies
  + 3.18: Add m4-common as a dependency of various modules
  + core-deps-3.18: Add missing WebKitGTK+ dependencies
  + gnome-world: Add gnome-games
  + gnome-world: Add jsk
  + gnome-world: retro-gtk add jsk deps
  + Revert ""Tag" libgit2-glib"
  + libgit2: update to version 0.23.0
  + Add --exit-on-error option
  + Updated Portuguese translation
  + Updated Spanish translation
  + Updated Spanish translation
  + Updated Czech translation
  + gnome-apps: add gnome-todo
  + gnome-apps: update gnome-calendar dependencies
  + core-deps-3.18: WebKitGTK+ 2.9.4
  + Add gnome-builder to meta-gnome-apps-tested
  + core-deps: Add libgrss as dependency of tracker
  + gnome-world: Add gnome-news
  + core-deps: WebKit should suggest more gstreamer plugins
  + core-deps: WebKit should require enchant and sqlite
  + core-deps: remove libxslt suggestion from WebKit
  + core-deps: Alphabetize WebKit dependencies
  + Revert "core-deps: remove libxslt suggestion from WebKit"
  + core-deps: Add missing WebKit dependencies
  + sysdeps: add libXrender
  + core-deps: Clean up WebKit's X11 and Wayland dependencies
  + Updated Greek translation
  + Updated Indonesian translation
  + core-deps-3.18: WebKitGTK+ 2.9.5
  + Updated Swedish translation
  + libgit2: update to version 0.23.1
  + core-deps: libsoup depends on vala
  + core-deps-3.16: WebKitGTK+ 2.8.5
  + 3.18: add m4-common as a dependency of GtkSourceView
  + gnome-suites-core-deps-3.18: remove autogenarg for
    GtkSourceView
  + core-deps: Again use ld.gold for linking WebKit
  + Add a missing comma
  + cmake: collect args from cmakeargs and makeargs tags
  + core-deps: Use cmakeargs instead of autogenargs in WebKit
  + core: NetworkManager depends on readline
  + gnome-suites-core-deps-3.18: clutter requires libinput and
    libxkbcommon
  + core-deps-3.18: WebKitGTK+ 2.9.90
  + Revert "gnome-suites-core-deps-3.18: clutter requires libinput
    and libxkbcommon"
  + tracker: Set bash-completion-dir explicitly
  + gnome-world: Add retro-plugins-snes
  + Set gitg branch to gnome-3-18
  + Bump up the Cogl branch for 3.18
  + Add some missing deps on m4-common
  + Remove deps on nonexistant polkit module
  + Update dependencies of fwupd
  + gnome-world: Update gnome-games deps
  + Build fwupd with --disable-colorhug
  + Add clang and llvm sysdeps, needed for gnome-builder
  + sysdeps-3.18: Use a regular file in llvm sysdep instead of a
    directory
  + gnome-world: abiword depends on boost
  + core-deps-3.18: WebKitGTK+ 2.9.91
  + git: fix current branch detection
  + gnome-world: Add retro-plugins-nes
  + gnome-world: Add retro-plugins-game-boy
  + gnome-world: Update gnome-games deps
  + Disks now depends on m4-common
  + Build various modules using --with-systemdsystemunitdir=no
  + Build gdm using --with-log-dir
  + Build PackageKit with --disable-bash-completion
  + Build zeitgeist with --with-session-bus-services-dir
  + Updated Spanish translation
  + vte depends on vala
  + epiphany, disks depend on appstream-glib
  + Build cogl without -Werror
  + 3.18: Make dleyna-renderer a sysdeps module
  + 3.18: Make libdmapsharing a sysdeps module
  + apps-3.18: Use tarball of fwupd
  + apps-3.18: cheese has been ported to clutter-gst3
  + gnome-world: Update retro-gtk deps
  + gnome-world: use network-manager-applet nma-1-0 branch
  + sysdeps-3.18: Remove py2cairo
  + Add Polish translation
  + apps-3.18: Switch Rygel branch for 3.18
  + core-deps-3.18: WebKitGTK+ 2.9.92
  + Updated Korean translation
  + core-deps-3.18: WebKitGTK+ 2.10.0
  + 3.18: Fix grilo module dependencies
  + 3.18: Use 0.2.x branches for grilo{,-plugins}
  + sysdeps-3.18: use llvm-config to detect clang
  + 3.16, 3.18: Remove duplicate network-manager-applet dep
  + 3.16, 3.18: Re-add network-manager-applet to core
  + 3.18: Add libchamplain as a dep of gnome-contacts
  + 3.18: gnome-shell switched to AX_COMPILER_FLAGS
  + 3.18: Add missing maintainer dependencies to geocode-glib
  + 3.18: Make gcab depend on gobject-introspection
  + 3.18: Use latest spice releases
  + sysdeps-3.18: raise python2 requirement to 2.7
  + GTK+ depends on wayland-egl
  + Updated Brazilian Portuguese translation
  + Updated Brazilian Portuguese translation
  + 3.18: Add appstream-glib dependency to polari
  + core-deps-3.18: XWayland depends on xorg-xproto
  + modulesets/gnome-sysdeps-3.18: need 7.0.28 version of
    xorg-xproto
  + 3.18: Build xorg-proto as the version needed is too recent
  + 3.18: Use GStreamer 1.6 branches
  + core-deps-3.18: gtkmm depends on cairomm
  + 3.18: Build cairomm instead use -sysdeps
  + core-deps: Add pcre2 as a dependency of vte
  + 3.18: Branch glib and glib-networking for 2.46
  + gnome-apps-3.18: dconf-editor will use AppStream.
  + 3.18: cairo depends on librsvg
  + Add GNOME 3.20 modulesets
  + core-deps-3.20: gobject-introspection has been ported to
    python3
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0~20150323:
  + world: change gitorious url
  + 3.16: Use the 0.28 branch of vala
  + 3.16: branch modules
  + core-deps-3.16: WebKitGTK+ 2.8.0
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.16.0~20150318:
  + Updated Swedish translation
  + core-deps-3.16: WebKitGTK+ 2.7.91
  + core-deps-3.16: Fix geoip tarball location and upgrade to 1.6.5
  + core-deps-3.16: Upgrade ibus to 1.5.10
  + 3.16: Move ibus-hangul to sysdeps
  + 3.16: Move anthy to -sysdeps
  + 3.16: Move pyzy to -sysdeps
  + sysdeps-3.16: Remove sqlite-bin, no package depends on it
  + 3.16: Move sbc to -sysdeps
  + 3.16: Move js24 to -sysdeps
  + core-deps-3.16: ATK doesnt depend on gnome-common anymore
  + gnome-apps-3.16: update spice-gtk to 0.28
  + gnome-apps-3.16: fix spice-gtk 0.28 sha256
  + core-3.16: g-o-a now requires WebKit2
  + core-deps-3.16: Add a patch for WebKit
  + gnome-apps-3.16: Make explicit g-i-s's dep on WebKit
  + Update Sound Juicer dependencies
  + core-3.16: compile Empathy with --enable-goa=no
  + Revert "core-3.16: compile Empathy with --enable-goa=no"
  + core-deps-3.16: uhttpmock is now on github
  + core-deps-3.16: Update ibus-anthy to latest stable (1.5.6)
  + sysdeps-3.16: Add libpinyin
  + core-deps-3.16: Add ibus-libpinyin
  + core-3.16: Use ibus-libpinyin instead ibus-pinyin
  + 3.16: Do not build ibus-pinyin
  + core-deps-3.16: Remove old ibus tarball repo
  + sysdeps-3.16: Add libhangul
  + 3.16: Build latest ibus-hangul (1.5.0) from tarball
  + Added Bosnian translation
  + sysdeps-3.16: Give up on installing python-rdflib
  + core-deps-3.16: Fix hash value for ibus-libpinyin
  + Updated Spanish translation
  + core-deps-3.16: add gcab
  + core-deps-3.16: build gcab from git
  + core-deps-3.16: WebKitGTK+ 2.7.92
  + 3.16: Use the glib-2-44 branch
  + 3.16: Use the gtk-3-16 branch
  + distribute $(sitecustomize_DATA)
  + fix mostly minor XML validation errors
  + release: 3.15.92
  + fill NEWS file
* Thu Feb 26 2015 dimstar@opensuse.org
- Update to version 3.16.0~20150225:
  + sysdeps-3.16: add libssh
  + apps-3.16: libgit2 should be built with SSH support
  + sysdeps-3.16: fixup for libssh
  + sysdeps-3.16: another fixup for libssh
  + gnome-world: remove some CVS modules
  + cvs: don't write empty passwords to ~/.cvspass
  + 3.16: rename libssh to libssh2
  + triggers: fix LiteralMatch vs REMatch problems
  + Switch cogl branch to 1.20
  + Updated Greek translation
- Add create-deps.sh: Extract dependencies from the provided
  modulesets. Version specified by moduleset defines (currently set
  to be 3.16).
* Sun Apr 27 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Bugs fixed: bgo#655714, bgo#669721, bgo#693052, bgo#697401,
    bgo#701181, bgo#704768, bgo#705506, bgo#707174, bgo#710236,
    bgo#712147, bgo#712305, bgo#712312, bgo#712351, bgo#715102,
    bgo#719759, bgo#720068, bgo#720083, bgo#720118, bgo#720119,
    bgo#720129, bgo#720285, bgo#720486, bgo#720547, bgo#720562,
    bgo#720574, bgo#720654, bgo#720755, bgo#720756, bgo#720839,
    bgo#721323, bgo#721378, bgo#721532, bgo#721801, bgo#721808,
    bgo#722098, bgo#722239, bgo#722561, bgo#722978, bgo#723070,
    bgo#723080, bgo#723082, bgo#723313, bgo#723416, bgo#723436,
    bgo#723494, bgo#723700, bgo#723945, bgo#723947, bgo#723948,
    bgo#723959, bgo#723966, bgo#723971, bgo#723973, bgo#724116,
    bgo#724622, bgo#724801, bgo#724993, bgo#727508.
  + Updated translations.
* Sat Nov 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Bugs fixed: bgo#644643, bgo#654582, bgo#656081, bgo#668368,
    bgo#670240, bgo#681342, bgo#681344, bgo#682104, bgo#682262,
    bgo#682951, bgo#683374, bgo#683408, bgo#683416, bgo#683566,
    bgo#683624, bgo#683639, bgo#683832, bgo#683846, bgo#683848,
    bgo#684205, bgo#684335, bgo#684652, bgo#684796, bgo#684878,
    bgo#684883, bgo#684908, bgo#685042, bgo#685149, bgo#685150,
    bgo#685264, bgo#685268, bgo#685335, bgo#685337, bgo#685348,
    bgo#685349, bgo#685350, bgo#685351, bgo#685489, bgo#686019,
    bgo#686906, bgo#687203, bgo#687272, bgo#687403, bgo#687601,
    bgo#687692, bgo#687699, bgo#687715, bgo#687716, bgo#687720,
    bgo#687743, bgo#687814, bgo#687837, bgo#687891, bgo#688011,
    bgo#688062, bgo#688075, bgo#688119, bgo#688696, bgo#688828,
    bgo#688846, bgo#688872, bgo#689010, bgo#689011, bgo#689194,
    bgo#689196, bgo#689226, bgo#689227, bgo#689228, bgo#689507,
    bgo#689755, bgo#690103, bgo#691395, bgo#691407, bgo#691408,
    bgo#691412, bgo#692390, bgo#692565, bgo#692675, bgo#692709,
    bgo#692825, bgo#693451, bgo#693729, bgo#693788, bgo#694452,
    bgo#694466, bgo#694527, bgo#694900, bgo#695271, bgo#695751,
    bgo#696081, bgo#696082, bgo#696144, bgo#696184, bgo#696294,
    bgo#696784, bgo#696887, bgo#697818, bgo#697875, bgo#697925,
    bgo#698108, bgo#698684, bgo#699928, bgo#699931, bgo#699936,
    bgo#699938, bgo#700475, bgo#700557, bgo#700731, bgo#700834,
    bgo#701051, bgo#701059, bgo#701147, bgo#701181, bgo#701776,
    bgo#701868, bgo#702020, bgo#702065, bgo#702603, bgo#702682,
    bgo#702776, bgo#702777, bgo#702805, bgo#702830, bgo#703633,
    bgo#703698, bgo#703954, bgo#704768, bgo#705136, bgo#705496,
    bgo#705996, bgo#706497, bgo#706518, bgo#707009, bgo#707174,
    bgo#707561, bgo#707843, bgo#708376, bgo#709019, bgo#710569,
    bgo#712147, bgo#712150, bgo#712305, bgo#712312.
* Sun Dec  9 2012 dimstar@opensuse.org
- Add patch recommends: several upstream scripts might require some
  patches to be applied (bnc#626149).
* Thu Sep  6 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Bugs fixed: bgo#656081, bgo#660844, bgo#670213, bgo#670240,
    bgo#681289, bgo#681290, bgo#681342, bgo#681886, bgo#682904,
    bgo#682951, bgo#683408
  + Updated translations.
* Mon Aug 13 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Offer to git clean -dfx over "make distclean" (bgo#656081)
  + Enhance system dependencies beyond pkg-config to detect include
    files & executable files (bgo#671042)
  + Bugs fixed: bgo#581515, bgo#672697, bgo#678361, bgo#678709,
    bgo#678869, bgo#679022, bgo#679375, bgo#679643, bgo#679792,
    bgo#679817, bgo#679948, bgo#679966, bgo#680389, bgo#681113.
  + Updated translations.
* Fri Jul 20 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Add ability to "skip-install" (bgo#612886)
  + Work with defaults if no ~/.jbuildrc exists (bgo#655763)
  + Inform user if required system dependencies are missing
    (bgo#669554)
  + Make --no-network more useful for tarball modules (bgo#670696)
  + Display circular dependencies in 'jhbuild checkmodulesets'
    command (bgo#676224)
  + Bugs fixed: bgo#581515, bgo#646510, bgo#655501, bgo#656818,
    bgo#667586, bgo#668368, bgo#669369, bgo#670220, bgo#670225,
    bgo#670335, bgo#670683, bgo#670696, bgo#670814, bgo#672205,
    bgo#672974, bgo#673202, bgo#673329, bgo#673987, bgo#674010,
    bgo#674315, bgo#674353, bgo#675416, bgo#675570, bgo#676490,
    bgo#677271, bgo#677860, bgo#677979, bgo#678132, bgo#678159,
    bgo#678372, bgo#678704, bgo#678723, bgo#678802, bgo#678958,
    bgo#679124, bgo#679407.
  + Updated translations.
* Wed Apr 18 2012 dimstar@opensuse.org
- Update to version 3.4.0:
  + Use parallel make by default.
  + Remove arch support.
  + Use new documentation infrastructure.
  + Many updates to modulesets.
  + Bugs fixed: bgo#634985, bgo#650533, bgo#654555, bgo#654686,
    bgo#654872, bgo#655164, bgo#655688, bgo#656399, bgo#656789,
    bgo#658601, bgo#660939, bgo#661010, bgo#661367, bgo#661412,
    bgo#661533, bgo#661641, bgo#661848, bgo#662392, bgo#662928,
    bgo#663003, bgo#663189, bgo#663255, bgo#663839, bgo#664154,
    bgo#664230, bgo#664231, bgo#664304, bgo#664796, bgo#665030,
    bgo#665499, bgo#666425, bgo#666546, bgo#666577, bgo#668107,
    bgo#668368, bgo#668434, bgo#668879, bgo#669205, bgo#669437,
    bgo#669475, bgo#669589, bgo#669658, bgo#669750, bgo#669953,
    bgo#669956, bgo#670094, bgo#670123, bgo#670127, bgo#670154,
    bgo#670343, bgo#670349, bgo#670533, bgo#670625, bgo#670698,
    bgo#670774, bgo#670799, bgo#670801, bgo#670917, bgo#670940,
    bgo#670943, bgo#670993, bgo#671162, bgo#671217, bgo#671226,
    bgo#671353, bgo#671365, bgo#671460, bgo#671634, bgo#671697,
    bgo#671700, bgo#671789, bgo#671891, bgo#672172, bgo#672206,
    bgo#672266, bgo#672634, bgo#673950, bgo#673957, bgo#673994,
    bgo#673999, bgo#674007.
  + Updated translations.
- Replace gnome-doc-utils-devel with yelp-tools-devel, following
  upstream change.
* Sat Oct  8 2011 zaitor@opensuse.org
- Update to version 3.2.1:
  + Bugs fixed:
  - bgo#653050, "jhbuild make" command.
  - bgo#648990, bgo#654701, bgo#655164, bgo#655417, bgo#660455,
    bgo#660527, bgo#660853, bgo#660939, bgo#660995, bgo#661010.
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Many changes in how jhbuild works internally.
  + Many moduleset changes.
  + Many bugs fixed (see NEWS for details).
  + Updated translations.
* Sun Feb 20 2011 vuntz@opensuse.org
- Add source-highlight Recommends to recommended-deps subpackage:
  it's useful with gtk-doc.
* Thu Feb 17 2011 vuntz@opensuse.org
- Change mozilla-xulrunner192-devel Recommends to
  mozilla-xulrunner20-devel. That's what we want people to use now
  :-)
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Dec 22 2010 vuntz@opensuse.org
- Update to version 2.32.4:
  + Improvements in handling of git modules.
  + Improvements in cmake support.
  + Add support for distcheck to jhbuild autobuild command.
  + Prefer configure over autogen.sh for tarballs.
  + Restore support for absolute moduleset paths.
  + Many other bug fixes: bgo#560237, bgo#599212, bgo#602682,
    bgo#610054, bgo#610943, bgo#616659, bgo#618499, bgo#618992,
    bgo#619659, bgo#621152, bgo#621194, bgo#622287, bgo#622316,
    bgo#622542, bgo#622859, bgo#623230, bgo#623425, bgo#623439,
    bgo#623500, bgo#623662, bgo#623668, bgo#623768, bgo#623930,
    bgo#623931, bgo#624077, bgo#624079, bgo#624436, bgo#624969,
    bgo#626039, bgo#626042, bgo#626288, bgo#626369, bgo#626808,
    bgo#626839, bgo#627576, bgo#628339, bgo#628368, bgo#628556,
    bgo#628560, bgo#628738, bgo#629240, bgo#629316, bgo#630079,
    bgo#630726, bgo#631108, bgo#631354, bgo#631583, bgo#632265,
    bgo#632435, bgo#632843, bgo#632859, bgo#632863, bgo#633740,
    bgo#633751, bgo#633794, bgo#633850, bgo#634373, bgo#634382,
    bgo#634866, bgo#634867, bgo#634953, bgo#635081, bgo#635498,
    bgo#635551, bgo#635862, bgo#636032, bgo#636169, bgo#636196,
    bgo#636199, bgo#636205, bgo#636253, bgo#636359, bgo#636595,
    bgo#636618, bgo#636772, bgo#636823, bgo#636877, bgo#636921,
    bgo#637098, bgo#637119, bgo#637218, bgo#637488, bgo#637513,
    bgo#637550, bgo#637728.
  + Documentation improvements.
* Sat Nov  6 2010 vuntz@opensuse.org
- Add gcc-c++ Recommends to jhbuild-recommended-deps: we need a c++
  compiler too.
* Fri Sep 10 2010 vuntz@opensuse.org
- Change liboil-devel Recommends to orc, since this is what
  GStreamer uses now.
- Drop clutter-cairo-devel, libtelepathy-devel Recommends: they are
  dead.
- Update sample.jhbuildrc to mention GNOME 2.32 instead of GNOME
  2.28.
* Mon Aug  9 2010 vuntz@opensuse.org
- Update to version 2.30.2:
  + bgo#592438: "bot --step check" doesn't do anything
  + bgo#597954: '--clean' argument/makeclean configuration option
    problems
  + bgo#606218: autotools: chmod +x configure
  + bgo#606360: commands: add help
  + bgo#606398: log slave config parsing errors
  + bgo#606658: cleanone needs network access
  + bgo#608322: jhbuild fails to clone gstreamer
  + bgo#608840: system man pages don't work inside jhbuild
  + bgo#608845: jhbuild autobuild --clean does not clean
  + bgo#613917: add support for buildbot 0.7.12
  + bgo#614948: po/Makefile.in.in is broken, translations aren't
    installed
  + bgo#614957: Manual Frequently Asked Questions, Building GNOME
    instructions inaccurate
  + bgo#615413: README and INSTALL files out of date
  + bgo#615473: Various fixes for testmodule modules
  + bgo#615802: Out of the source tree builds and autoreconf
  + bgo#615803: DTD is not complete
  + bgo#616593: [docs] branch, repo atrributes & cvs/svn progs
  + bgo#617114: Bzr improvements
  + bgo#617794: jhbuild unusable in some locales
  + bgo#618254: build_policy updated and updated-deps should honor
    dirty git worktrees
  + bgo#618609: cloning does not consider git user accounts
  + bgo#618974: Restructure the _update member of GitBranch
  + bgo#619525: [3.0] libproxy ignores python installed by jhbuild
  + bgo#619935: [info] Additional output for git branches
  + bgo#619940: [cleanone] Restrict execution to the 'clean' phase
  + bgo#620648: [info] Display the source directory for all branch
    types
  + bgo#620974: [doc] Document git branch attributes
  + bgo#621461: Automatically set GI_TYPELIB_PATH
  + Other bugs fixed: bgo#560237, bgo#581262, bgo#581515,
    bgo#596385, bgo#598524, bgo#604204, bgo#605932, bgo#606217,
    bgo#606924, bgo#608520, bgo#608521, bgo#608875, bgo#609250,
    bgo#609366, bgo#609368, bgo#609455, bgo#609874, bgo#610024,
    bgo#610936, bgo#610943, bgo#611283, bgo#612297, bgo#615801,
    bgo#616104, bgo#616417, bgo#617083, bgo#617099, bgo#617200,
    bgo#617270, bgo#618301, bgo#618313, bgo#618855, bgo#618865,
    bgo#619000, bgo#619002, bgo#620729, bgo#620741, bgo#621199,
    bgo#621206, bgo#621280, bgo#621855, bgo#622129
  + Updated translations.
* Wed Mar 31 2010 vuntz@opensuse.org
- Update recommends of recommended-deps to the current state:
  + Remove dbus-1-python, hal-devel, DeviceKit-disks-devel,
    DeviceKit-power-devel, mozilla-xulrunner191-devel,
    libggz2-devel, ggz-client-libs-devel, PolicyKit-devel,
    PolicyKit-gnome-devel.
  + Add dbus-1-python-devel, libdevkit-power-gobject-devel,
    udisks-devel, mozilla-xulrunner192-devel.
* Tue Jan 19 2010 vuntz@opensuse.org
- Update to version 2.29.3:
  + Fixed bugs:
  - bgo#587489, Crash when checking out pango
  - bgo#591231, BuildBot: add support for using the "Nightly"
    scheduler (instead of "Periodic")
  - bgo#601276, Please add at-spi2-core, at-spi2-atk, and
    pyatspi2
  - bgo#605101, Remove evolution-data-server-dbus
  - bgo#606099, Jhbuild installs gobject-introspection 0.6.5
    while some modules require 0.6.7
  - bgo#606222, Removing obsolete dependencies in
    gnome-suites-2.30.modules
  + Updated translations.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 2.29.2:
  + Fixed bugs:
  - bgo#531543, Allow selective choice of poisoning dep tree
  - bgo#560092, Jhbuild should use XDG_CACHE_HOME
  - bgo#591239, add check for wget/curl in sanitycheck
  - bgo#592433, add command and option to run build phase
    "check"
  - bgo#595730, Manual should refer to sample.jhbuildrc and not
    mention GNOME svn
  - bgo#596129, add nm-applet plugins
  - bgo#596905, Better documentation of branches variable
  - bgo#597437, 'jhbuild run --inbuilddir=module' doesn't work
  - bgo#598391, Manual doesn't document module_makecheck
  - bgo#598537, where is libnl?
  - bgo#598689, where is pyxdg?
  - bgo#601324, Add a new module: PyGI
  + Updated translations.
* Thu Oct  1 2009 vuntz@opensuse.org
- Update to version 2.28.0:
  + Fixed bugs:
  - bgo#106737, "start at" Option for "jhbuild update"
  - bgo#583515, Selecting [1] rerun stage configure after
    configure failure runs build
  - bgo#589326, nss fails to build due to incompatible
    /usr/lib/libplc4.so
  - bgo#590273, When a git clone is interrupted during the
    compressing objects state, there's no way to recover from it
    automatically.
  - bgo#591142, Clean up deprecated dependencies in
    gnome-suites-2.28.modules
  - bgo#591470, jhbuild can't "switch" to gnome-2-28 branch
  - bgo#591508, should strip .git from repo name when finding
    checkout dir name
  - bgo#591553, support msdos-created zipfiles
  - bgo#592427, Wrong python2.6 path
  - bgo#592438, "bot --step check" doesn't do anything
  - bgo#592558, Python path depending on the prefix
  - bgo#592602, Add gnome-pilot
  - bgo#592801, some spelling and grammar mistakes
  - bgo#594135, Documentation could provide examples in section
    Configuration File Reference
  - bgo#594981, Support configuring a buildroot for out of tree
    builds
  - bgo#595440, [2.28] Epiphany branch gnome-2-28 does not exist
  - bgo#595441, Brasero 2.28 branch should be brasero-2-28, not
    gnome-2-28
  + Updated translations.
* Wed Aug 12 2009 vuntz@novell.com
- Update to version 2.27.90:
  + Fixed bugs:
  - bgo#583515, Selecting [1] rerun stage configure after
    configure failure runs build
  - bgo#589237, libchamplain vs clutter-cairo-0.8 vs clutter-0.9
  - bgo#590064, Set ACLOCAL as well as ACLOCAL_FLAGS
  - bgo#590102, move gnome-js-common and gobject-introspection to
    external deps?
  - bgo#590103, Crash if hash="" in moduleset
  - bgo#590273, When a git clone is interrupted during the
    compressing objects state, there's no way to
    recover from it automatically.
  - bgo#590359, Remove libgail-gnome where possible
  - bgo#591142, Clean up deprecated dependencies in
    gnome-suites-2.28.modules
  - bgo#591236, Review all clutter stuff
  - bgo#591470, jhbuild can't "switch" to gnome-2-28 branch
* Fri Jul 31 2009 vuntz@novell.com
- Update to version 2.27.5:
  + Fixed bugs:
  - bgo#588928, Don't try to import md5 twice
  - bgo#582446, Options and commands containing the word
    "checkout" can be confused with git's meaning of
    "checkout"
  - bgo#584322, [gnome-2.28] add gnome-js-common and update seed
    dependency
  - bgo#585996, force_checkout considered harmful with git
  - bgo#588688, Update modest repository
  - bgo#588862, Update mono to 2.4.2.2
  - bgo#589227, WebKit module fetched from wrong moduleset
  - bgo#589234, Dates, Tasks and Contacts are now in git.gnome.org
  - bgo#589296, Build pulseaudio before gst-plugins-good
  - bgo#589383, loudmouth module fails checkout
  - bgo#589482, Add claws-mail repo
  - bgo#589660, pango has a soft dependency on
    gobject-introspection
  - bgo#589762, Balsa branch seems to be outdated
  - bgo#589767, Add midori repo
  - bgo#590103, Crash if hash="" in moduleset
- Add Recommends on DeviceKit-disks-devel, libgudev-1_0-devel,
  polkit-devel, libchamplain-devel, libgdata-devel, gmime-2_4-devel
  to recommended-deps package.
- Update sample.jhbuildrc accordingly.
- Remove Recommends on DeviceKit-devel since it will be obsolete.
* Wed Jun 17 2009 vuntz@novell.com
- Update to version 2.27.3:
  + Major changes:
  - Rewritten GUI
  - Many win32 improvements
  + Fixed bugs:
  - bgo#584283, endless loop when executing command "clean" if
    the module type doesn't support it
  - bgo#581515, Don't build DeviceKit-disks by default
  - bgo#582165, Fix gui option
  - bgo#582490, Jhbuild crashing (NameError)
  - bgo#583455, [win32 fixes] jhbuild uses subprocess.Popen
    incompatibly with win32
  - bgo#583838, libtool 2.x breaks guile build
  - bgo#583849, output directory for tinderbox build not
    configurable on the command line
  - bgo#583969, update should be possible from dvcs_mirror_dir
    with --no- network
  - bgo#584028, bootstrap: gmp fails to build on amd64 (Intel
    E5450)
  - bgo#584052, Missing dependency in jhbuild
  - bgo#585084, Fix Fill & Expand properties on preferences
    window
  - bgo#585787, Perl modules don't build
- Add python-gtk Requires for the GUI.
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.27.2:
  + Updated building state machine to an inter-phases dependency
    system
  + Added support for more options in buildbot slave xml
    description
  + Improved autotoolization
  + Bugs fixed:
  - bgo#119088, Best effort flag
  - bgo#143221, Maybe add "jhbuild clean"
  - bgo#368820, Should reload jhbuildrc after configure failure
  - bgo#385120, should GTK_MODULES be unset ?
  - bgo#400302, add support for module uninstalling
  - bgo#419879, [RFC] consider having -HEAD modulesets
  - bgo#560688, Use xulrunner for mozilla module
  - bgo#580815, jhbuild git copy checkout mode broken
  - bgo#580910, cp in jhbuild copy checkout mode needs -f for svn
  - bgo#580949, jhbuild does not create copy_dir
  - bgo#581232, [patch] add (g)parted
  - bgo#581262, FTBFS: libsndfile: libsqlite3.so: undefined
    reference to `dlsym'
  - bgo#581515, Don't build DeviceKit-disks by default
  - bgo#581547, build -C shouldn't nuke modules that have .git
  - bgo#581634, Do not force writable prefix for some commands
  - bgo#581981, fix git-cvsimport update
  - bgo#582172, Tarball not buildable (?)
  - bgo#582177, [misc] Make .desktop file valid
  - bgo#582180, jhbuild/main.py is not executable and contains
    "#!/usr/bin/env python"
  - bgo#582193, anjuta should suggest glade3
  - bgo#582490, Jhbuild crashing (NameError)
  - bgo#582754, tracker depends on raptor, which jhbuild knows
    nothing about
  - bgo#582802, base: fix can't find bootstrap moduleset
  - bgo#582829, use PKGDATADIR to find patches directory
  - bgo#582930, tarball modules don't honour global makeargs
  - bgo#583006, AttributeError: 'MetaModule' object has no
    attribute 'do_checkout'
  - bgo#583227, jhbuildrc include support
  - bgo#583294, pyxdg should be an external dependency
  - bgo#583309, gnome-icon-theme should depend on glib
  - bgo#583420, crash when trying to apply patches for
    hicolor-icon-theme
  - bgo#583453, [win32 fixes] inpath and has_command should take
    .exe extension into account
  - bgo#583518, --no-poison only works sometimes
  - bgo#583532, buildbot directory is not installed properly to
    create a server
- Drop jhbuild-fix-build.patch: fixed upstream.
- Drop jhbuild.in: upstream tarball now correctly installs it.
- Drop jhbuild.desktop: gui mode is broken right now. Upstream will
  install it when it will be fixed.
* Mon May 11 2009 vuntz@novell.com
- Initial packaging.
